@@ -37,19 +37,16 @@ def get_anomaly_detection_jobs(
     offset: int,
     limit: int,
     sort: str,
-    experimentId: Union[str, None] = None,
-    useCaseId: Union[str, None] = None,
+    experiment_id: Union[str, None] = None,
+    useCase_id: Union[str, None] = None,
     type: Union[str, None] = None,
 ) -> List[AnomalyDetection]:
-  payload = AnomalyDetectionListPayload(experimentId=experimentId, useCaseId=useCaseId, sort=sort, type=type, limit=limit, offset=offset)
-
-  return execute_request(
-      credentials=credentials,
-      method='get',
-      path=f'/detection-jobs',
-      params=payload
+  payload = AnomalyDetectionListPayload(
+      experimentId=experiment_id, useCaseId=useCase_id, sort=sort, type=type, limit=limit, offset=offset
   )
 
+  return execute_request(credentials=credentials, method='get', path=f'/detection-jobs', params=payload)
+
 
 def get_anomaly_detection_table_results(credentials: Credentials, id: str) -> pd.DataFrame:
   response = execute_request(
