@@ -60,15 +60,17 @@ class Tim:
 
     return UploadDatasetResponse(metadata, logs)
 
-  def create_forecast(self, dataset_id: str, job_configuration: CreateForecastConfiguration) -> str:
+  def create_forecast(
+      self, dataset_id: str, job_configuration: Union[CreateForecastConfiguration, None] = None
+  ) -> str:
     """Create a forecast job in the workspace the dataset is connected to (the default workspace)
 
     Parameters
     ----------
     dataset_id : str
         The ID of a dataset in the TIM repository
-    job_configuration : CreateForecastConfiguration
-        TIM Engine model building and forecasting configuration
+    job_configuration : CreateForecastConfiguration, Optional
+        TIM Engine model building and forecasting configuration, by default None
         Available keys are: name, configuration, data
 
     Returns
@@ -86,12 +88,14 @@ class Tim:
         credentials=self.__credentials, configuration=use_case_configuration
     )['id']
 
-    job_configuration_with_use_case_id = ForecastJobConfiguration(
-        name=job_configuration['name'],
-        useCaseId=created_use_case_id,
-        configuration=job_configuration['configuration'],
-        data=job_configuration['data'],
-    )
+    job_configuration_with_use_case_id = ForecastJobConfiguration(useCaseId=created_use_case_id)
+
+    if job_configuration:
+      if 'name' in job_configuration: job_configuration_with_use_case_id['name'] = job_configuration['name']
+      if 'configuration' in job_configuration:
+        job_configuration_with_use_case_id['configuration'] = job_configuration['configuration']
+      if 'data' in job_configuration: job_configuration_with_use_case_id['data'] = job_configuration['data']
+
     model = create_forecast(
         credentials=self.__credentials, job_configuration=job_configuration_with_use_case_id
     )
@@ -349,7 +353,7 @@ class Tim:
       self,
       offset: int = 0,
       limit: int = 10000,
-      userGroupId: Union[str, None] = None,
+      user_group_id: Union[str, None] = None,
       sort: Union[str, None] = None
   ) -> List[Workspace]:
     """Get a list of workspaces
@@ -357,22 +361,22 @@ class Tim:
     Parameters
     ----------
     offset : int, optional
-        Number of records to be skipped from beggining of the list, by default 0
+        Number of records to be skipped from beginning of the list, by default 0
     limit : int, optional
         Maximum number of records to be returned, by default 10000
-    userGroupId : Union[str, None], optional
+    user_group_id : Union[str, None], optional
         User Group ID, by default None
     sort : Union[str, None], optional
         Sorting output by the chosen attribute. +/- indicates ascending/descending order, by default -createdAt
         Available values : +createdAt, -createdAt, +updatedAt, -updatedAt, +title, -title
     """
-    return get_workspaces(self.__credentials, offset, limit, userGroupId, sort)
+    return get_workspaces(self.__credentials, offset, limit, user_group_id, sort)
 
   def get_datasets(
       self,
       offset: int = 0,
       limit: int = 10000,
-      workspaceId: Union[str, None] = None,
+      workspace_id: Union[str, None] = None,
       sort: Union[str, None] = None
   ) -> List[Dataset]:
     """Get a list of datasets
@@ -380,16 +384,16 @@ class Tim:
     Parameters
     ----------
     offset : int, optional
-        Number of records to be skipped from beggining of the list, by default 0
+        Number of records to be skipped from beginning of the list, by default 0
     limit : int, optional
         Maximum number of records to be returned, by default 10000
-    workspaceId : Union[str, None] = None
+    workspace_id : Union[str, None] = None
         Filter for specific Workspace, by default None
     sort : Union[str, None] = None
         Sorting output by the chosen attribute. +/- indicates ascending/descending order.
         Available values : +createdAt, -createdAt
     """
-    return get_datasets(self.__credentials, offset, limit, workspaceId, sort)
+    return get_datasets(self.__credentials, offset, limit, workspace_id, sort)
 
   def get_dataset_versions(
       self,
@@ -414,8 +418,8 @@ class Tim:
       self,
       offset: int = 0,
       limit: int = 10000,
-      experimentId: Union[str, None] = None,
-      useCaseId: Union[str, None] = None,
+      experiment_id: Union[str, None] = None,
+      useCase_id: Union[str, None] = None,
       type: Union[str, None] = None,
       sort: str = '-createdAt'
   ) -> List[AnomalyDetection]:
@@ -427,9 +431,9 @@ class Tim:
         Number of records to be skipped from beggining of the list, by default 0
     limit : int, optional
         Maximum number of records to be returned, by default 10000
-    experimentId : Union[str, None], optional
+    experiment_id : Union[str, None], optional
         Filter for specific Experiment, by default None
-    useCaseId : Union[str, None], optional
+    useCase_id : Union[str, None], optional
         Filter for specific Use Case, by default None
     type : Union[str, None], optional
         Filter for specific types (comma separated string), by default None
@@ -438,7 +442,9 @@ class Tim:
         Sorting output by the chosen attribute. +/- indicates ascending/descending order, by default '-createdAt'
         Available values : +createdAt, -createdAt, +executedAt, -executedAt, +completedAt, -completedAt, +priority, -priority
     """
-    return get_anomaly_detection_jobs(self.__credentials, offset, limit, sort, experimentId, useCaseId, type)
+    return get_anomaly_detection_jobs(
+        self.__credentials, offset, limit, sort, experiment_id, useCase_id, type
+    )
 
   @property
   def credentials(self):
